@@ -1,12 +1,10 @@
 #include <QCommandLineParser>
 #include <QDate>
-#include <QFileInfo>
 #include <QIcon>
 
 #include <QQmlApplicationEngine>
 #include <QQmlContext>
 
-
 #ifdef Q_OS_ANDROID
 #include <QGuiApplication>
 #include <MauiKit/Core/mauiandroid.h>
@@ -16,7 +14,6 @@
 
 #include <MauiKit/Core/mauiapp.h>
 
-#include "pdfdocument.h"
 //#include "epubreader.h"
 
 #include "library.h"
@@ -32,9 +29,7 @@
 int main(int argc, char *argv[])
 {
     QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
-    QCoreApplication::setAttribute(Qt::AA_DontCreateNativeWidgetSiblings);
     QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-    QCoreApplication::setAttribute(Qt::AA_DisableSessionManager, true);
 
 #ifdef Q_OS_ANDROID
     QGuiApplication app(argc, argv);
@@ -50,7 +45,7 @@ int main(int argc, char *argv[])
     MauiApp::instance ()->setIconName ("qrc:/assets/shelf.svg");
 
     KLocalizedString::setApplicationDomain("shelf");
-    KAboutData about(QStringLiteral("shelf"), i18n("Shelf"), SHELF_VERSION_STRING, i18n("Browse and view your documents."), KAboutLicense::LGPL_V3, i18n("© 2019-%1 Nitrux Development Team", QString::number(QDate::currentDate().year())), QString(GIT_BRANCH) + "/" + QString(GIT_COMMIT_HASH));
+    KAboutData about(QStringLiteral("shelf"), i18n("Shelf"), SHELF_VERSION_STRING, i18n("Browse and view your documents."), KAboutLicense::LGPL_V3, i18n("© 2019-%1 Maui Development Team", QString::number(QDate::currentDate().year())), QString(GIT_BRANCH) + "/" + QString(GIT_COMMIT_HASH));
     about.addAuthor(i18n("Camilo Higuita"), i18n("Developer"), QStringLiteral("milo.h@aol.com"));
     about.setHomepage("https://mauikit.org");
     about.setProductName("maui/shelf");
@@ -61,21 +56,35 @@ int main(int argc, char *argv[])
     KAboutData::setApplicationData(about);
 
     QCommandLineParser parser;
-    parser.process(app);
 
     about.setupCommandLine(&parser);
+    parser.process(app);
+
     about.processCommandLine(&parser);
+    const QStringList args = parser.positionalArguments();
+
+    Library library;
 
-    //    Library library;
     QQmlApplicationEngine engine;
-    qmlRegisterType<PdfDocument>("PDF", 1, 0, "Document");
-//	qmlRegisterType<EpubReader>("EPUB", 1, 0, "Document");
-    qmlRegisterType<LibraryModel>(SHELF_URI, 1, 0, "LibraryList");
-//    qmlRegisterType<Cloud>("CloudList", 1, 0, "CloudList");
+    const QUrl url(QStringLiteral("qrc:/main.qml"));
+    QObject::connect(
+                &engine,
+                &QQmlApplicationEngine::objectCreated,
+                &app,
+                [url, args, &library](QObject *obj, const QUrl &objUrl) {
+        if (!obj && url == objUrl)
+            QCoreApplication::exit(-1);
 
-    engine.load(QUrl(QStringLiteral("qrc:/main.qml")));
-    if (engine.rootObjects().isEmpty())
-        return -1;
+        if (!args.isEmpty())
+            library.openFiles(args);
+    },
+    Qt::QueuedConnection);
+
+    //	qmlRegisterType<EpubReader>("EPUB", 1, 0, "Document");
+    qmlRegisterType<LibraryModel>(SHELF_URI, 1, 0, "LibraryList");
+    qmlRegisterSingletonInstance<Library>(SHELF_URI, 1, 0, "Library", &library);
+
+    engine.load(url);
 
     return app.exec();
 }
