@@ -1,15 +1,21 @@
 #include "librarymodel.h"
 
-#include <MauiKit/FileBrowsing/tagging.h>
 #include <MauiKit/FileBrowsing/fileloader.h>
 #include <MauiKit/FileBrowsing/fmstatic.h>
 
 #include <MauiKit/Core/fmh.h>
 
+static FMH::MODEL fileData(const QUrl &url)
+{
+    FMH::MODEL model;
+    model = FMStatic::getFileInfoModel(url);
+    model.insert(FMH::MODEL_KEY::PREVIEW, "image://preview/"+url.toString());
+    return model;
+}
+
 LibraryModel::LibraryModel(QObject *parent) : MauiList(parent)
   , m_fileLoader(new FMH::FileLoader(parent))
 {
-    qDebug()<< "CREATING GALLERY LIST";
     qRegisterMetaType<LibraryModel*>("const LibraryModel*");
 
     connect(m_fileLoader, &FMH::FileLoader::itemsReady,[this](FMH::MODEL_LIST items)
@@ -19,11 +25,11 @@ LibraryModel::LibraryModel(QObject *parent) : MauiList(parent)
         emit this->postItemAppended();
         emit this->countChanged();
     });
-
 }
 
 void LibraryModel::setList()
 {
+    this->m_fileLoader->informer = &fileData;
     this->m_fileLoader->requestPath({FMStatic::DesktopPath, FMStatic::DownloadsPath, FMStatic::DocumentsPath, FMStatic::CloudCachePath}, true, FMStatic::FILTER_LIST[FMStatic::FILTER_TYPE::DOCUMENT]);
 }
 
@@ -75,6 +81,7 @@ void LibraryModel::clear()
     emit this->preListChanged();
     this->list.clear();
     emit this->postListChanged();
+    emit this->countChanged();
 }
 
 void LibraryModel::componentComplete()
